shell

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package shell provides shell fixture implementations for testing.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Shell

type Shell struct {
	// contains filtered or unexported fields
}

Shell is a struct that implements the process.Shell interface and executes commands inside a Docker container.

func NewShell

func NewShell(
	ctr tc.Container,
	wkdir string,
) *Shell

NewShell creates a new Shell instance that executes commands inside the specified Docker container and working directory.

func (*Shell) Execution

func (s *Shell) Execution(
	ctx context.Context,
	cmd command.Command,
) proc.Execution

Execution executes the given command and returns its execution result.

It runs the command inside the specified Docker container and working directory.

Jump to